@@ -18,6 +18,9 @@ fragment metadataEntryFragment on EventMetadataEntry {
         module
         name
     }
+    ... on EventFloatMetadataEntry {
+        value
+    }
 }
 
 fragment stepEventFragment on StepEvent {
@@ -101,9 +104,7 @@ LAUNCH_PIPELINE_EXECUTION_RESULT_FRAGMENT = '''
             invalidOutputName
         }
         ... on PipelineConfigValidationInvalid {
-            pipeline {
-                name
-            }
+            pipelineName
             errors {
                 __typename
                 message
@@ -118,8 +119,12 @@ LAUNCH_PIPELINE_EXECUTION_RESULT_FRAGMENT = '''
         ... on PythonError {
             message
             stack
+            cause {
+                message
+                stack
+            }
         }
-        ... on LaunchPipelineExecutionSuccess {
+        ... on LaunchPipelineRunSuccess {
             run {
                 runId
                 pipeline {
@@ -127,16 +132,6 @@ LAUNCH_PIPELINE_EXECUTION_RESULT_FRAGMENT = '''
                         name
                     }
                 }
-                logs {
-                    nodes {
-                        __typename
-                        ... on MessageEvent {
-                            message
-                            level
-                        }
-                        ...stepEventFragment
-                    }
-                }
                 tags {
                     key
                     value
@@ -149,20 +144,10 @@ LAUNCH_PIPELINE_EXECUTION_RESULT_FRAGMENT = '''
 START_PIPELINE_EXECUTION_RESULT_FRAGMENT = '''
     fragment startPipelineExecutionResultFragment on StartPipelineExecutionResult {
         __typename
-        ... on StartPipelineExecutionSuccess {
+        ... on StartPipelineRunSuccess {
             run {
                 runId
                 pipeline { ...on PipelineReference { name } }
-                logs {
-                    nodes {
-                        __typename
-                        ... on MessageEvent  {
-                            message
-                            level
-                        }
-                        ...stepEventFragment
-                    }
-                }
                 tags {
                     key
                     value
@@ -170,7 +155,7 @@ START_PIPELINE_EXECUTION_RESULT_FRAGMENT = '''
             }
         }
         ... on PipelineConfigValidationInvalid {
-            pipeline { name }
+            pipelineName
             errors { message }
         }
         ... on PipelineNotFoundError {
@@ -178,13 +163,83 @@ START_PIPELINE_EXECUTION_RESULT_FRAGMENT = '''
         }
         ... on PythonError {
             message
+            stack
+            cause {
+                message
+                stack
+            }
+        }
+    }
+'''
+
+
+START_PIPELINE_EXECUTION_FOR_CREATED_RUN_RESULT_FRAGMENT = '''
+    fragment startPipelineExecutionForCreatedRunResultFragment on StartPipelineExecutionForCreatedRunResult {
+        __typename
+        ... on StartPipelineRunSuccess {
+            run {
+                runId
+                pipeline { ...on PipelineReference { name } }
+                tags {
+                    key
+                    value
+                }
+            }
+        }
+        ... on PipelineConfigValidationInvalid {
+            pipelineName
+            errors { message }
+        }
+        ... on PipelineNotFoundError {
+            pipelineName
+        }
+        ... on PythonError {
+            message
+            stack
+            cause {
+                message
+                stack
+            }
+        }
+        ... on PipelineRunNotFoundError {
+            message
+        }
+    }
+'''
+
+START_PIPELINE_REEXECUTION_RESULT_FRAGMENT = '''
+    fragment startPipelineReexecutionResultFragment on StartPipelineReexecutionResult {
+        __typename
+        ... on StartPipelineRunSuccess {
+            run {
+                runId
+                pipeline { ...on PipelineReference { name } }
+                tags {
+                    key
+                    value
+                }
+            }
+        }
+        ... on PipelineConfigValidationInvalid {
+            pipelineName
+            errors { message }
+        }
+        ... on PipelineNotFoundError {
+            pipelineName
+        }
+        ... on PythonError {
+            message
+            stack
+            cause {
+                message
+                stack
+            }
         }
     }
 '''
 
 START_PIPELINE_EXECUTION_QUERY = (
-    FRAGMENTS
-    + START_PIPELINE_EXECUTION_RESULT_FRAGMENT
+    START_PIPELINE_EXECUTION_RESULT_FRAGMENT
     + '''
 
 mutation (
@@ -199,9 +254,41 @@ mutation (
 '''
 )
 
+START_PIPELINE_EXECUTION_FOR_CREATED_RUN_QUERY = (
+    START_PIPELINE_EXECUTION_FOR_CREATED_RUN_RESULT_FRAGMENT
+    + '''
+
+mutation (
+    $runId: String!
+) {
+    startPipelineExecutionForCreatedRun(
+        runId: $runId
+    ) {
+        ...startPipelineExecutionForCreatedRunResultFragment
+    }
+}
+'''
+)
+
+
+START_PIPELINE_REEXECUTION_QUERY = (
+    START_PIPELINE_REEXECUTION_RESULT_FRAGMENT
+    + '''
+
+mutation (
+    $executionParams: ExecutionParams!
+) {
+    startPipelineReexecution(
+        executionParams: $executionParams
+    ) {
+        ...startPipelineReexecutionResultFragment
+    }
+}
+'''
+)
+
 START_SCHEDULED_EXECUTION_QUERY = (
-    FRAGMENTS
-    + START_PIPELINE_EXECUTION_RESULT_FRAGMENT
+    START_PIPELINE_EXECUTION_RESULT_FRAGMENT
     + LAUNCH_PIPELINE_EXECUTION_RESULT_FRAGMENT
     + '''
 
@@ -222,6 +309,14 @@ mutation (
             __typename
             message
         }
+        ... on PythonError {
+            message
+            stack
+            cause {
+                message
+                stack
+            }
+        }
         ...startPipelineExecutionResultFragment
         ...launchPipelineExecutionResultFragment
     }
@@ -230,9 +325,7 @@ mutation (
 )
 
 
-START_PIPELINE_EXECUTION_SNAPSHOT_QUERY = (
-    FRAGMENTS
-    + '''
+START_PIPELINE_EXECUTION_SNAPSHOT_QUERY = '''
 mutation (
     $executionParams: ExecutionParams!
 ) {
@@ -240,18 +333,9 @@ mutation (
         executionParams: $executionParams
     ) {
         __typename
-        ... on StartPipelineExecutionSuccess {
+        ... on StartPipelineRunSuccess {
             run {
                 pipeline { ...on PipelineReference { name } }
-                logs {
-                    nodes {
-                        __typename
-                        ... on MessageEvent {
-                            level
-                        }
-                        ...stepEventFragment
-                    }
-                }
                 tags {
                     key
                     value
@@ -259,7 +343,52 @@ mutation (
             }
         }
         ... on PipelineConfigValidationInvalid {
-            pipeline { name }
+            pipelineName
+            errors { message }
+        }
+        ... on PipelineNotFoundError {
+            pipelineName
+        }
+        ... on InvalidStepError {
+            invalidStepKey
+        }
+        ... on InvalidOutputError {
+            stepKey
+            invalidOutputName
+        }
+        ... on PythonError {
+            message
+            stack
+            cause {
+                message
+                stack
+            }
+        }
+    }
+}
+'''
+
+START_PIPELINE_REEXECUTION_SNAPSHOT_QUERY = '''
+mutation (
+    $executionParams: ExecutionParams!
+) {
+    startPipelineReexecution(
+        executionParams: $executionParams
+    ) {
+        __typename
+        ... on StartPipelineRunSuccess {
+            run {
+                pipeline { ...on PipelineReference { name } }
+                tags {
+                    key
+                    value
+                }
+                rootRunId
+                parentRunId
+            }
+        }
+        ... on PipelineConfigValidationInvalid {
+            pipelineName
             errors { message }
         }
         ... on PipelineNotFoundError {
@@ -275,7 +404,6 @@ mutation (
     }
 }
 '''
-)
 
 SUBSCRIPTION_QUERY = (
     FRAGMENTS
