@@ -6,25 +6,18 @@ from dagster_graphql.test.utils import execute_dagster_graphql
 from graphql import parse
 
 from dagster import check
-from dagster.core.definitions.pipeline import PipelineRunsFilter
 from dagster.core.instance import DagsterInstance
-from dagster.core.storage.intermediate_store import build_fs_intermediate_store
+from dagster.core.storage.pipeline_run import PipelineRunsFilter
 from dagster.core.utils import make_new_run_id
 from dagster.utils import file_relative_path, merge_dicts
 from dagster.utils.test import get_temp_file_name
 
 from .execution_queries import (
-    PIPELINE_REEXECUTION_INFO_QUERY,
+    START_PIPELINE_EXECUTION_FOR_CREATED_RUN_QUERY,
     START_PIPELINE_EXECUTION_QUERY,
-    START_PIPELINE_EXECUTION_SNAPSHOT_QUERY,
     SUBSCRIPTION_QUERY,
 )
-from .setup import (
-    PoorMansDataFrame,
-    csv_hello_world_solids_config,
-    csv_hello_world_solids_config_fs_storage,
-    define_test_context,
-)
+from .setup import csv_hello_world, csv_hello_world_solids_config, define_test_context
 from .utils import sync_execute_get_run_log_data
 
 
@@ -45,7 +38,7 @@ def test_basic_start_pipeline_execution():
     assert result.data
 
     # just test existence
-    assert result.data['startPipelineExecution']['__typename'] == 'StartPipelineExecutionSuccess'
+    assert result.data['startPipelineExecution']['__typename'] == 'StartPipelineRunSuccess'
     assert uuid.UUID(result.data['startPipelineExecution']['run']['runId'])
     assert result.data['startPipelineExecution']['run']['pipeline']['name'] == 'csv_hello_world'
 
@@ -63,11 +56,33 @@ def test_basic_start_pipeline_execution_with_preset():
     assert result.data
 
     # just test existence
-    assert result.data['startPipelineExecution']['__typename'] == 'StartPipelineExecutionSuccess'
+    assert result.data['startPipelineExecution']['__typename'] == 'StartPipelineRunSuccess'
     assert uuid.UUID(result.data['startPipelineExecution']['run']['runId'])
     assert result.data['startPipelineExecution']['run']['pipeline']['name'] == 'csv_hello_world'
 
 
+def test_basic_start_pipeline_execution_with_pipeline_def_tags():
+    result = execute_dagster_graphql(
+        define_test_context(),
+        START_PIPELINE_EXECUTION_QUERY,
+        variables={
+            'executionParams': {'selector': {'name': 'hello_world_with_tags'}, 'mode': 'default',},
+        },
+    )
+
+    assert not result.errors
+    assert result.data['startPipelineExecution']['run']['tags'] == [
+        {'key': 'tag_key', 'value': 'tag_value'}
+    ]
+
+    # just test existence
+    assert result.data['startPipelineExecution']['__typename'] == 'StartPipelineRunSuccess'
+    assert uuid.UUID(result.data['startPipelineExecution']['run']['runId'])
+    assert (
+        result.data['startPipelineExecution']['run']['pipeline']['name'] == 'hello_world_with_tags'
+    )
+
+
 def test_basic_start_pipeline_execution_with_non_existent_preset():
     with pytest.raises(UserFacingGraphQLError) as exc_info:
         execute_dagster_graphql(
@@ -254,10 +269,7 @@ def _get_step_run_log_entry(pipeline_run_logs, step_key, typename):
 
 
 def test_basic_sync_execution_no_config():
-    context = define_test_context()
-    result = execute_dagster_graphql(
-        context,
-        START_PIPELINE_EXECUTION_QUERY,
+    result = sync_execute_get_run_log_data(
         variables={
             'executionParams': {
                 'selector': {'name': 'no_config_pipeline'},
@@ -266,10 +278,7 @@ def test_basic_sync_execution_no_config():
             }
         },
     )
-
-    assert not result.errors
-    assert result.data
-    logs = result.data['startPipelineExecution']['run']['logs']['nodes']
+    logs = result['messages']
     assert isinstance(logs, list)
     assert has_event_of_type(logs, 'PipelineStartEvent')
     assert has_event_of_type(logs, 'PipelineSuccessEvent')
@@ -277,10 +286,7 @@ def test_basic_sync_execution_no_config():
 
 
 def test_basic_inmemory_sync_execution():
-    context = define_test_context()
-    result = execute_dagster_graphql(
-        context,
-        START_PIPELINE_EXECUTION_QUERY,
+    result = sync_execute_get_run_log_data(
         variables={
             'executionParams': {
                 'selector': {'name': 'csv_hello_world'},
@@ -290,10 +296,7 @@ def test_basic_inmemory_sync_execution():
         },
     )
 
-    assert not result.errors
-    assert result.data
-
-    logs = result.data['startPipelineExecution']['run']['logs']['nodes']
+    logs = result['messages']
     assert isinstance(logs, list)
     assert has_event_of_type(logs, 'PipelineStartEvent')
     assert has_event_of_type(logs, 'PipelineSuccessEvent')
@@ -306,10 +309,7 @@ def test_basic_inmemory_sync_execution():
 
 
 def test_basic_filesystem_sync_execution():
-    context = define_test_context()
-    result = execute_dagster_graphql(
-        context,
-        START_PIPELINE_EXECUTION_QUERY,
+    result = sync_execute_get_run_log_data(
         variables={
             'executionParams': {
                 'selector': {'name': 'csv_hello_world'},
@@ -321,10 +321,7 @@ def test_basic_filesystem_sync_execution():
         },
     )
 
-    assert not result.errors
-    assert result.data
-
-    logs = result.data['startPipelineExecution']['run']['logs']['nodes']
+    logs = result['messages']
     assert isinstance(logs, list)
     assert has_event_of_type(logs, 'PipelineStartEvent')
     assert has_event_of_type(logs, 'PipelineSuccessEvent')
@@ -360,183 +357,6 @@ def get_step_output_event(logs, step_key, output_name='result'):
     return None
 
 
-def test_successful_pipeline_reexecution(snapshot):
-    def sanitize_result_data(result_data):
-        if isinstance(result_data, dict):
-            if 'path' in result_data:
-                result_data['path'] = 'DUMMY_PATH'
-            result_data = {k: sanitize_result_data(v) for k, v in result_data.items()}
-        elif isinstance(result_data, list):
-            for i in range(len(result_data)):
-                result_data[i] = sanitize_result_data(result_data[i])
-        else:
-            pass
-        return result_data
-
-    run_id = make_new_run_id()
-    instance = DagsterInstance.ephemeral()
-    result_one = execute_dagster_graphql(
-        define_test_context(instance=instance),
-        START_PIPELINE_EXECUTION_SNAPSHOT_QUERY,
-        variables={
-            'executionParams': {
-                'selector': {'name': 'csv_hello_world'},
-                'environmentConfigData': csv_hello_world_solids_config_fs_storage(),
-                'executionMetadata': {'runId': run_id},
-                'mode': 'default',
-            }
-        },
-    )
-
-    assert (
-        result_one.data['startPipelineExecution']['__typename'] == 'StartPipelineExecutionSuccess'
-    )
-
-    snapshot.assert_match(sanitize_result_data(result_one.data))
-
-    expected_value_repr = (
-        '''[OrderedDict([('num1', '1'), ('num2', '2'), ('sum', 3), '''
-        '''('sum_sq', 9)]), OrderedDict([('num1', '3'), ('num2', '4'), ('sum', 7), '''
-        '''('sum_sq', 49)])]'''
-    )
-
-    store = build_fs_intermediate_store(instance.intermediates_directory, run_id)
-    assert store.has_intermediate(None, 'sum_solid.compute')
-    assert store.has_intermediate(None, 'sum_sq_solid.compute')
-    assert (
-        str(store.get_intermediate(None, 'sum_sq_solid.compute', PoorMansDataFrame).obj)
-        == expected_value_repr
-    )
-
-    new_run_id = make_new_run_id()
-
-    result_two = execute_dagster_graphql(
-        define_test_context(instance=instance),
-        START_PIPELINE_EXECUTION_SNAPSHOT_QUERY,
-        variables={
-            'executionParams': {
-                'selector': {'name': 'csv_hello_world'},
-                'environmentConfigData': csv_hello_world_solids_config_fs_storage(),
-                'stepKeys': ['sum_sq_solid.compute'],
-                'executionMetadata': {'runId': new_run_id},
-                'mode': 'default',
-                'retryRunId': run_id,
-            }
-        },
-    )
-
-    query_result = result_two.data['startPipelineExecution']
-    assert query_result['__typename'] == 'StartPipelineExecutionSuccess'
-    logs = query_result['run']['logs']['nodes']
-
-    assert isinstance(logs, list)
-    assert has_event_of_type(logs, 'PipelineStartEvent')
-    assert has_event_of_type(logs, 'PipelineSuccessEvent')
-    assert not has_event_of_type(logs, 'PipelineFailureEvent')
-
-    assert not get_step_output_event(logs, 'sum_solid.compute')
-    assert get_step_output_event(logs, 'sum_sq_solid.compute')
-
-    snapshot.assert_match(sanitize_result_data(result_two.data))
-
-    store = build_fs_intermediate_store(instance.intermediates_directory, new_run_id)
-    assert not store.has_intermediate(None, 'sum_solid.inputs.num.read', 'input_thunk_output')
-    assert store.has_intermediate(None, 'sum_solid.compute')
-    assert store.has_intermediate(None, 'sum_sq_solid.compute')
-    assert (
-        str(store.get_intermediate(None, 'sum_sq_solid.compute', PoorMansDataFrame).obj)
-        == expected_value_repr
-    )
-
-
-def test_pipeline_reexecution_info_query(snapshot):
-    context = define_test_context()
-
-    run_id = make_new_run_id()
-    execute_dagster_graphql(
-        context,
-        START_PIPELINE_EXECUTION_SNAPSHOT_QUERY,
-        variables={
-            'executionParams': {
-                'selector': {'name': 'csv_hello_world'},
-                'environmentConfigData': csv_hello_world_solids_config_fs_storage(),
-                'executionMetadata': {'runId': run_id},
-                'mode': 'default',
-            }
-        },
-    )
-
-    new_run_id = make_new_run_id()
-    execute_dagster_graphql(
-        context,
-        START_PIPELINE_EXECUTION_SNAPSHOT_QUERY,
-        variables={
-            'executionParams': {
-                'selector': {'name': 'csv_hello_world'},
-                'environmentConfigData': csv_hello_world_solids_config_fs_storage(),
-                'stepKeys': ['sum_sq_solid.compute'],
-                'executionMetadata': {'runId': new_run_id},
-                'mode': 'default',
-                'retryRunId': run_id,
-            }
-        },
-    )
-
-    result_one = execute_dagster_graphql(
-        context, PIPELINE_REEXECUTION_INFO_QUERY, variables={'runId': run_id}
-    )
-    query_result_one = result_one.data['pipelineRunOrError']
-    assert query_result_one['__typename'] == 'PipelineRun'
-    assert query_result_one['stepKeysToExecute'] is None
-
-    result_two = execute_dagster_graphql(
-        context, PIPELINE_REEXECUTION_INFO_QUERY, variables={'runId': new_run_id}
-    )
-    query_result_two = result_two.data['pipelineRunOrError']
-    assert query_result_two['__typename'] == 'PipelineRun'
-    stepKeysToExecute = query_result_two['stepKeysToExecute']
-    print(query_result_two)
-    assert stepKeysToExecute is not None
-    snapshot.assert_match(stepKeysToExecute)
-
-
-def test_pipeline_reexecution_invalid_step_in_subset():
-    run_id = make_new_run_id()
-    execute_dagster_graphql(
-        define_test_context(),
-        START_PIPELINE_EXECUTION_SNAPSHOT_QUERY,
-        variables={
-            'executionParams': {
-                'selector': {'name': 'csv_hello_world'},
-                'environmentConfigData': csv_hello_world_solids_config(),
-                'executionMetadata': {'runId': run_id},
-                'mode': 'default',
-            }
-        },
-    )
-
-    new_run_id = make_new_run_id()
-
-    result_two = execute_dagster_graphql(
-        define_test_context(),
-        START_PIPELINE_EXECUTION_SNAPSHOT_QUERY,
-        variables={
-            'executionParams': {
-                'selector': {'name': 'csv_hello_world'},
-                'environmentConfigData': csv_hello_world_solids_config(),
-                'stepKeys': ['nope'],
-                'executionMetadata': {'runId': new_run_id},
-                'mode': 'default',
-                'retryRunId': run_id,
-            }
-        },
-    )
-
-    query_result = result_two.data['startPipelineExecution']
-    assert query_result['__typename'] == 'InvalidStepError'
-    assert query_result['invalidStepKey'] == 'nope'
-
-
 def test_basic_start_pipeline_execution_with_tags():
     instance = DagsterInstance.ephemeral()
     result = execute_dagster_graphql(
@@ -554,7 +374,7 @@ def test_basic_start_pipeline_execution_with_tags():
 
     assert not result.errors
     assert result.data
-    assert result.data['startPipelineExecution']['__typename'] == 'StartPipelineExecutionSuccess'
+    assert result.data['startPipelineExecution']['__typename'] == 'StartPipelineRunSuccess'
 
     run = result.data['startPipelineExecution']['run']
     run_id = run['runId']
@@ -624,6 +444,38 @@ def test_start_pipeline_execution_with_start_disabled():
     )
 
     assert result.data
+    assert result.data['startPipelineExecution']['__typename'] == 'StartPipelineRunDisabledError'
+
+
+def test_start_pipeline_execution_for_created_run():
+    instance = DagsterInstance.local_temp()
+
+    pipeline_run = instance.create_run_for_pipeline(
+        pipeline_def=csv_hello_world, environment_dict=csv_hello_world_solids_config()
+    )
+
+    result = execute_dagster_graphql(
+        define_test_context(instance=instance),
+        START_PIPELINE_EXECUTION_FOR_CREATED_RUN_QUERY,
+        variables={'runId': pipeline_run.run_id},
+    )
+    assert result.data
     assert (
-        result.data['startPipelineExecution']['__typename'] == 'StartPipelineExecutionDisabledError'
+        result.data['startPipelineExecutionForCreatedRun']['__typename']
+        == 'StartPipelineRunSuccess'
+    )
+
+
+def test_start_pipeline_execution_for_created_run_not_found():
+    run_id = make_new_run_id()
+    result = execute_dagster_graphql(
+        define_test_context(),
+        START_PIPELINE_EXECUTION_FOR_CREATED_RUN_QUERY,
+        variables={'runId': run_id},
+    )
+
+    assert result.data
+    assert (
+        result.data['startPipelineExecutionForCreatedRun']['__typename']
+        == 'PipelineRunNotFoundError'
     )
